@@ -12,10 +12,10 @@ from typing import Optional, List, Union
 
 
 class BoundingBox(BaseModel):
-    x: float
-    y: float
-    w: float
-    h: float
+    xMin: float
+    yMin: float
+    xMax: float
+    yMax: float
     value: str
 
     @root_validator
@@ -41,8 +41,8 @@ class BoundingBox(BaseModel):
     #     return values
 
 
-class Polygon(BaseModel):
-    pass
+# class Polygon(BaseModel):
+#     pass
 
 
 class Classification(BaseModel):
@@ -54,7 +54,7 @@ class Classification(BaseModel):
 class Objects(BaseModel):
     model_name: str
     type: str
-    objects: Union[List[BoundingBox], List[Polygon]]
+    objects: List[BoundingBox]
 
 
 class Prediction(BaseModel):
